@@ -18,3 +18,12 @@ def run(rout, dfx_file, log_path):
     executor = Executor(rout)
     result, pass_count, fail_count = executor.execute(dfx_file, log_path)
     return result, pass_count, fail_count
+
+
+def version():
+    """
+    return dfx version
+    :return:
+    """
+    this_version = "1.1.0"
+    return this_version
\ No newline at end of file
